@@ -41,8 +41,6 @@
 
 #define KIOWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KIOWIDGETS_NO_DEPRECATED) && !defined(KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KIOWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOWIDGETS_NO_DEPRECATED
-#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KIOWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KIOWIDGETS_DEPRECATED
-#  define KIOWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KIOWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KIOWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -289,6 +287,12 @@
 #else
 #  define KIOWIDGETS_DEPRECATED_VERSION_5_103(text)
 #endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56b00
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_107(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_107(text)
+#endif
 #define KIOWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
